==> genometools-1.2.0.tar.gz: genometools-1.2.0/src/extended/genome_node_rep.h <==
/*
  Copyright (c) 2006-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef GENOME_NODE_REP_H
#define GENOME_NODE_REP_H

#include <stdio.h>
#include "core/dlist.h"
#include "extended/genome_node.h"

/* the ``genome node'' interface */
struct GtGenomeNodeClass
{
  size_t size;
  void    (*free)(GtGenomeNode*);
  GtStr*  (*get_seqid)(GtGenomeNode*);
  GtStr*  (*get_idstr)(GtGenomeNode*);
  GtRange (*get_range)(GtGenomeNode*);
  void    (*set_range)(GtGenomeNode*, GtRange);
  void    (*change_seqid)(GtGenomeNode*, GtStr*);
  int     (*accept)(GtGenomeNode*, GtNodeVisitor*, GtError*);
};

struct GtGenomeNode
{
  const GtGenomeNodeClass *c_class;
  GtStr *filename;
  unsigned int line_number,
               reference_count;
};

GtGenomeNode* gt_genome_node_create(const GtGenomeNodeClass*);

#endif

==> genometools-1.3.0.tar.gz: genometools-1.3.0/src/extended/genome_node_rep.h <==
/*
  Copyright (c) 2006-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef GENOME_NODE_REP_H
#define GENOME_NODE_REP_H

#include <stdio.h>
#include "core/dlist.h"
#include "extended/genome_node.h"

/* the ``genome node'' interface */
struct GtGenomeNodeClass
{
  size_t size;
  void    (*free)(GtGenomeNode*);
  GtStr*  (*get_seqid)(GtGenomeNode*);
  GtStr*  (*get_idstr)(GtGenomeNode*);
  GtRange (*get_range)(GtGenomeNode*);
  void    (*set_range)(GtGenomeNode*, const GtRange*);
  void    (*change_seqid)(GtGenomeNode*, GtStr*);
  int     (*accept)(GtGenomeNode*, GtNodeVisitor*, GtError*);
};

struct GtGenomeNode
{
  const GtGenomeNodeClass *c_class;
  GtStr *filename;
  unsigned int line_number,
               reference_count;
};

GtGenomeNode* gt_genome_node_create(const GtGenomeNodeClass*);

#endif
